@@ -316,7 +316,6 @@ extractNEWS <- function(reposRoot, srcContrib, destDir) {
     extractNewsFromTarball <- function(tarball, unpackDir=".") {
         pkg <- pkgName(tarball)
         cleanUnpackDir(tarball, unpackDir, pattern="NEWS")
-        cat("Attempting to extract NEWS from", tarball, "\n")
         unpack(tarball, unpackDir, "'*NEWS*'")
     }
 
@@ -337,8 +336,14 @@ extractNEWS <- function(reposRoot, srcContrib, destDir) {
     if (!file.info(destDir)$isdir)
       stop("destDir must specify a directory")
     unpackDir <- tempdir()
-    lapply(tarballs, extractNewsFromTarball, unpackDir=unpackDir)
-    lapply(tarballs, convertNEWSToText, srcDir=unpackDir, destDir=destDir)
+    lapply(tarballs, function(tarball) {
+        cat("Attempting to extract NEWS from", tarball, "\n")
+        extractNewsFromTarball(tarball, unpackDir=unpackDir)
+        res <- try(convertNEWSToText(tarball, srcDir=unpackDir,
+                                              destDir=destDir))
+        if (inherits(res, "try-error"))
+            cat("FAILED!\n")
+    })
 
     invisible(NULL)
 }
@@ -570,6 +575,16 @@ read_REPOSITORY <- function(reposRootPath)
     invisible(nrow(db))
 }
 
+## To manually run/debug write_VIEWS() on the central builder (e.g. on
+## nebbiolo2), start R-4.1 from the biocpush account and do:
+##   library(BiocManager)  # check that the Bioconductor version is correct
+##   repositories()        # check that all the repositories are correct
+##   library(biocViews)
+##   reposRoot <- "~/PACKAGES/3.14/bioc"
+##   manifestFile <- "~biocbuild/bbs-3.14-bioc/manifest/software.txt"
+##   meatPath <- "~biocbuild/bbs-3.14-bioc/MEAT0"
+##   setwd(reposRoot)
+##   write_VIEWS(reposRoot, manifestFile=manifestFile, meatPath=meatPath)
 write_VIEWS <- function(reposRootPath, fields = NULL,
                         verbose = FALSE, vignette.dir="vignettes",
                         manifestFile=NA, meatPath=NA
@@ -716,23 +731,26 @@ write_VIEWS <- function(reposRootPath, fields = NULL,
     colnames(dbMat) <- c(fldNames, "vignettes", "vignetteTitles", "hasREADME",
         "hasNEWS", "hasINSTALL", "hasLICENSE", "Rfiles")
 
-    # get reverse dependency list
-    dependsOnMe <- getReverseDepends(dbMat, "Depends")
+    # get reverse dependency list including CRAN
+    all_repos <- repositories()
+    all_pkgs <- available.packages(repos = all_repos)
+    mm = match(dbMat[,"Package"], all_pkgs[,"Package"])
+
+
+    dependsOnMe <- getReverseDepends(all_pkgs, "Depends")[mm]
     dbMat <- cbind(dbMat, dependsOnMe)
-    importsMe <- getReverseDepends(dbMat, "Imports")
+    importsMe <- getReverseDepends(all_pkgs, "Imports")[mm]
     dbMat <- cbind(dbMat, importsMe)
-    suggestsMe <- getReverseDepends(dbMat, "Suggests")
+    suggestsMe <- getReverseDepends(all_pkgs, "Suggests")[mm]
     dbMat <- cbind(dbMat, suggestsMe)
-    linksToMe <- getReverseDepends(dbMat, "LinkingTo")
+    linksToMe <- getReverseDepends(all_pkgs, "LinkingTo")[mm]
     dbMat <- cbind(dbMat, linksToMe)
 
 
     # add (recursive) dependency count for badge on landing page
-    all_repos <- repositories()
-    all_pkgs <- available.packages(repos = all_repos)
     bioc_pkgs <- available.packages(repos = all_repos[setdiff(names(all_repos),
                                         "CRAN")] )
-    deps <- package_dependencies(rownames(bioc_pkgs), db = all_pkgs,
+    deps <- tools::package_dependencies(rownames(bioc_pkgs), db = all_pkgs,
                                  recursive=TRUE)
     numDeps <- lengths(deps)
     dependencyCount <-  numDeps[dbMat[, "Package"]]
@@ -760,51 +778,20 @@ write_VIEWS <- function(reposRootPath, fields = NULL,
             add_mat[,which(colnames(dbMat)=="Package")] = missing_pkgs
             if (!is.na(meatPath)){
             for(i in seq_along(missing_pkgs)){
-
                 add_mat = tryCatch({
-                    desc = read.dcf(file.path(meatPath, missing_pkgs[i],
-                        "DESCRIPTION"))
+                   desc <- tools:::.read_description(file.path(meatPath, missing_pkgs[i], "DESCRIPTION"))
 
-                    for (dx in colnames(desc)){
+                    for (dx in names(desc)){
                         if (dx %in% colnames(add_mat)){
-                            add_mat[i, which(colnames(add_mat) == dx)] = desc[,dx]
+                            add_mat[i, which(colnames(add_mat) == dx)] = desc[dx]
                         }else{
                             # check for Authors@R and parse accordingly
                             if (dx == "Authors@R"){
-                                ar = desc[,"Authors@R"]
-                                env <- new.env(parent=emptyenv())
-                                env[["c"]] = c
-                                env[["person"]] <- utils::person
-                                pp <- parse(text=ar, keep.source=TRUE)
-                                people =
-                                    tryCatch({
-                                        people <- eval(pp, env)
-                                        people
-                                    }, error=function(e) {
-                                        # could not parse Authors@R
-                                        people <- "ERROR"
-                                        people
-                                    }, warning = function(e){
-                                        people <- "ERROR"
-                                        people
-                                    })
-
-                                if (all(people == "ERROR")){
-                                    add_mat[i,which(colnames(dbMat)=="Maintainer")] = "ERROR"
-                                    add_mat[i,which(colnames(dbMat)=="Author")] = "ERROR"
-                                }else{
-                                    Author = paste0(unlist(people$given)," ", unlist(people$family), " <", unlist(people$email),">", collapse=", ")
-                                    add_mat[i,which(colnames(dbMat)=="Author")] = Author
-                                    idx = !is.na(unlist(lapply(people$role, FUN=match, x="cre")))
-                                    if (any(idx)){
-                                        people = people[idx]
-                                        add_mat[i,which(colnames(dbMat)=="Maintainer")] =
-                                            paste0(unlist(people$given)," ", unlist(people$family), " <", unlist(people$email),">", collapse=", ")
-                                    }else{
-                                        add_mat[i,which(colnames(dbMat)=="Maintainer")] = "ERROR"
-                                    }
-
-                                }
+                                authMain <-
+                                    tools:::.expand_package_description_db_R_fields(desc)
+                                add_mat[i,which(colnames(dbMat)=="Maintainer")] = authMain["Maintainer"]
+                                add_mat[i,which(colnames(dbMat)=="Author")] = authMain["Author"]
+  
                             }
                         }
                     }
@@ -818,8 +805,10 @@ write_VIEWS <- function(reposRootPath, fields = NULL,
                     add_mat[i,which(colnames(dbMat)=="Title")] = "ERROR"
                     add_mat
                 })
+
+   
+            }
             }
-        }
             # make sure necessary columns are not NA
             if (any(is.na(add_mat[,"Title"]))){
                 add_mat[which(is.na(add_mat[,"Title"])), "Title"] =
@@ -999,4 +988,3 @@ write_SYMBOLS <- function(dir, verbose=FALSE, source.dirs=FALSE) {
     close(con)
     NULL
 }
-
